@@ -25,8 +25,7 @@ struct user {
 	time_t last_pkt;
 	int seed;
 	in_addr_t tun_ip;
-	struct sockaddr host;
-	int addrlen;
+	struct in_addr host;
 	struct query q;
 	struct packet inpacket;
 	struct packet outpacket;
